@@ -4,20 +4,8 @@
  * Authors: Zeeshan Ali (Khattak) <zeeshan.ali@nokia.com>
  *                                <zeeshanak@gnome.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -26,6 +14,7 @@
  *
  * #GUPnPDIDLLiteItem respresents a DIDL-Lite item element.
  */
+#include <config.h>
 
 #include <string.h>
 
@@ -35,7 +24,7 @@
 
 G_DEFINE_TYPE (GUPnPDIDLLiteItem,
                gupnp_didl_lite_item,
-               GUPNP_TYPE_DIDL_LITE_OBJECT);
+               GUPNP_TYPE_DIDL_LITE_OBJECT)
 
 enum {
         PROP_0,
