@@ -3,20 +3,8 @@
  *
  * Authors: Zeeshan Ali (Khattak) <zeeshanak@gnome.org>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -27,6 +15,8 @@
  *
  */
 
+#include <config.h>
+
 #include <string.h>
 #include <ctype.h>
 #include "gupnp-av.h"
@@ -36,7 +26,7 @@
 
 G_DEFINE_TYPE (GUPnPDIDLLiteParser,
                gupnp_didl_lite_parser,
-               G_TYPE_OBJECT);
+               G_TYPE_OBJECT)
 
 enum {
         OBJECT_AVAILABLE,
@@ -54,21 +44,52 @@ verify_didl_attributes (xmlNode *node)
 
         content = av_xml_util_get_child_element_content (node, "date");
         if (content) {
+                enum {
+                        NONE,
+                        YEAR,
+                        YEARMONTH_HYPHEN,
+                        MONTH,
+                        MONTHDAY_HYPHEN,
+                        DAY,
+                        END
+                };
                 /* try to roughly verify the passed date with ^\d{4}-\d{2}-\d{2} */
                 char *ptr = (char *) content;
-                int state = 0;
+                int idx = 0, state = NONE;
                 while (*ptr) {
-                        if (state == 4 || state == 7) {
-                                if (*ptr != '-')
+                        switch (*ptr) {
+                        case '-':
+                                if (state == YEAR && idx == 4)
+                                        state = YEARMONTH_HYPHEN;
+                                else if (state == MONTH && (idx == 6 || idx == 7))
+                                        state = MONTHDAY_HYPHEN;
+                                else
                                         return FALSE;
-                        } else {
+                                break;
+                        default:
                                 if (!isdigit (*ptr))
                                         return FALSE;
+                                if (state == NONE)
+                                        state = YEAR;
+                                else if (state == YEARMONTH_HYPHEN)
+                                        state = MONTH;
+                                else if (state == MONTHDAY_HYPHEN)
+                                        state = DAY;
+                                else if (state == DAY) {
+                                        if (*(ptr-1) != '-' && *(ptr-2) != '-')
+                                                return FALSE;
+                                }
                         }
 
                         ptr++;
-                        state++;
-                        if (state == 10)
+                        idx++;
+                        if (*ptr == '\0') {
+                                if (state == DAY)
+                                        break;
+                                else
+                                        return FALSE;
+                        }
+                        if (idx == 10)
                                 break;
                 }
         }
@@ -240,12 +261,17 @@ gupnp_didl_lite_parser_parse_didl_recursive (GUPnPDIDLLiteParser *parser,
         GUPnPAVXMLDoc *xml_doc = NULL;
         gboolean       result;
 
-        doc = xmlRecoverMemory (didl, strlen (didl));
+        doc = xmlReadMemory (didl,
+                             strlen (didl),
+                             NULL,
+                             NULL,
+                             XML_PARSE_NONET | XML_PARSE_RECOVER);
         if (doc == NULL) {
                 g_set_error (error,
                              G_MARKUP_ERROR,
                              G_MARKUP_ERROR_PARSE,
-                             "Could not parse DIDL-Lite XML:\n%s", didl);
+                             "Could not parse DIDL-Lite XML:\n%s",
+                             didl);
 
                 return FALSE;
         }
