@@ -8,69 +8,35 @@
  *          Jorn Baayen <jorn@openedhand.com>
  *          Krzesimir Nowak <krnowak@openismus.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
-#ifndef __GUPNP_DIDL_LITE_RESOURCE_H__
-#define __GUPNP_DIDL_LITE_RESOURCE_H__
+#ifndef GUPNP_DIDL_LITE_RESOURCE_H
+#define GUPNP_DIDL_LITE_RESOURCE_H
 
 #include <stdarg.h>
 #include <glib-object.h>
 #include <glib.h>
 #include <libxml/tree.h>
-#include <libgupnp/gupnp.h>
 
 #include "gupnp-dlna.h"
 #include "gupnp-protocol-info.h"
 
 G_BEGIN_DECLS
 
-GType
-gupnp_didl_lite_resource_get_type (void) G_GNUC_CONST;
+
+G_DECLARE_DERIVABLE_TYPE(GUPnPDIDLLiteResource,
+                          gupnp_didl_lite_resource,
+                          GUPNP,
+                          DIDL_LITE_RESOURCE,
+                          GObject)
 
 #define GUPNP_TYPE_DIDL_LITE_RESOURCE \
                 (gupnp_didl_lite_resource_get_type ())
-#define GUPNP_DIDL_LITE_RESOURCE(obj) \
-                (G_TYPE_CHECK_INSTANCE_CAST ((obj), \
-                 GUPNP_TYPE_DIDL_LITE_RESOURCE, \
-                 GUPnPDIDLLiteResource))
-#define GUPNP_DIDL_LITE_RESOURCE_CLASS(obj) \
-                (G_TYPE_CHECK_CLASS_CAST ((obj), \
-                 GUPNP_TYPE_DIDL_LITE_RESOURCE, \
-                 GUPnPDIDLLiteResourceClass))
-#define GUPNP_IS_DIDL_LITE_RESOURCE(obj) \
-                (G_TYPE_CHECK_INSTANCE_TYPE ((obj), \
-                 GUPNP_TYPE_DIDL_LITE_RESOURCE))
-#define GUPNP_IS_DIDL_LITE_RESOURCE_CLASS(obj) \
-                (G_TYPE_CHECK_CLASS_TYPE ((obj), \
-                 GUPNP_TYPE_DIDL_LITE_RESOURCE))
-#define GUPNP_DIDL_LITE_RESOURCE_GET_CLASS(obj) \
-                (G_TYPE_INSTANCE_GET_CLASS ((obj), \
-                 GUPNP_TYPE_DIDL_LITE_RESOURCE, \
-                 GUPnPDIDLLiteResourceClass))
 
-typedef struct _GUPnPDIDLLiteResourcePrivate GUPnPDIDLLiteResourcePrivate;
 
-typedef struct {
-        GObject parent;
-
-        GUPnPDIDLLiteResourcePrivate *priv;
-} GUPnPDIDLLiteResource;
-
-typedef struct {
+struct _GUPnPDIDLLiteResourceClass {
         GObjectClass parent_class;
 
         /* future padding */
@@ -78,7 +44,7 @@ typedef struct {
         void (* _gupnp_reserved2) (void);
         void (* _gupnp_reserved3) (void);
         void (* _gupnp_reserved4) (void);
-} GUPnPDIDLLiteResourceClass;
+};
 
 void
 gupnp_didl_lite_resource_set_uri        (GUPnPDIDLLiteResource *resource,
