@@ -5,20 +5,8 @@
  * Authors: Jorn Baayen <jorn@openedhand.com>
  *          Jens Georg <jensg@openismus.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
 /**
@@ -28,6 +16,8 @@
  * #GUPnPDIDLLiteWriter is a helper class for writing DIDL-Lite fragments.
  */
 
+#include <config.h>
+
 #include <string.h>
 
 #include "gupnp-didl-lite-writer.h"
@@ -49,10 +39,11 @@ struct _GUPnPDIDLLiteWriterPrivate {
 
         char        *language;
 };
+typedef struct _GUPnPDIDLLiteWriterPrivate GUPnPDIDLLiteWriterPrivate;
 
 G_DEFINE_TYPE_WITH_PRIVATE (GUPnPDIDLLiteWriter,
                             gupnp_didl_lite_writer,
-                            G_TYPE_OBJECT);
+                            G_TYPE_OBJECT)
 
 enum {
         PROP_0,
@@ -175,6 +166,7 @@ is_standard_prop (const char *name,
         return strcmp (name, "id") == 0 ||
                strcmp (name, "parentID") == 0 ||
                strcmp (name, "restricted") == 0 ||
+               strcmp (name, "refID") == 0 ||
                (g_strcmp0 (namespace, "dc") == 0 &&
                 strcmp (name, "title") == 0) ||
                (g_strcmp0 (namespace, "upnp") == 0 &&
@@ -209,7 +201,6 @@ filter_attributes (xmlNode             *node,
 static void
 filter_node (xmlNode             *node,
              GList               *allowed,
-             GUPnPDIDLLiteWriter *writer,
              gboolean             tags_only)
 {
         xmlNode *child;
@@ -263,7 +254,7 @@ filter_node (xmlNode             *node,
         /* Recurse */
         for (child = node->children; child != NULL; child = child->next)
                 if (!xmlNodeIsText (child))
-                        filter_node (child, allowed, writer, tags_only);
+                        filter_node (child, allowed, tags_only);
 }
 
 static void
@@ -279,6 +270,9 @@ apply_filter (GUPnPDIDLLiteWriter *writer,
         g_return_if_fail (GUPNP_IS_DIDL_LITE_WRITER (writer));
         g_return_if_fail (filter != NULL);
 
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (writer);
+
         if (filter[0] == '*')
                 return;         /* Wildcard */
 
@@ -288,10 +282,8 @@ apply_filter (GUPnPDIDLLiteWriter *writer,
         for (i = 0; tokens[i] != NULL; i++)
                 allowed = g_list_append (allowed, tokens[i]);
 
-        for (node = writer->priv->xml_node->children;
-             node != NULL;
-             node = node->next)
-                filter_node (node, allowed, writer, tags_only);
+        for (node = priv->xml_node->children; node != NULL; node = node->next)
+                filter_node (node, allowed, tags_only);
 
         g_list_free (allowed);
         g_strfreev (tokens);
@@ -301,9 +293,6 @@ apply_filter (GUPnPDIDLLiteWriter *writer,
 static void
 gupnp_didl_lite_writer_init (GUPnPDIDLLiteWriter *writer)
 {
-        writer->priv = G_TYPE_INSTANCE_GET_PRIVATE (writer,
-                                                    GUPNP_TYPE_DIDL_LITE_WRITER,
-                                                    GUPnPDIDLLiteWriterPrivate);
 }
 
 static void
@@ -316,10 +305,12 @@ gupnp_didl_lite_writer_set_property (GObject      *object,
         GUPnPDIDLLiteWriter *writer;
 
         writer = GUPNP_DIDL_LITE_WRITER (object);
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (writer);
 
         switch (property_id) {
         case PROP_LANGUAGE:
-                writer->priv->language = g_value_dup_string (value);
+                priv->language = g_value_dup_string (value);
                 break;
         default:
                 G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
@@ -356,10 +347,11 @@ static void
 gupnp_didl_lite_writer_constructed (GObject *object)
 {
         GObjectClass               *object_class;
-        GUPnPDIDLLiteWriterPrivate *priv;
         xmlDoc                     *doc;
 
-        priv = GUPNP_DIDL_LITE_WRITER (object)->priv;
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (
+                        GUPNP_DIDL_LITE_WRITER (object));
 
         doc = xmlNewDoc ((unsigned char *) "1.0");
         priv->xml_doc = av_xml_doc_new (doc);
@@ -387,9 +379,9 @@ static void
 gupnp_didl_lite_writer_dispose (GObject *object)
 {
         GObjectClass               *object_class;
-        GUPnPDIDLLiteWriterPrivate *priv;
-
-        priv = GUPNP_DIDL_LITE_WRITER (object)->priv;
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (
+                        GUPNP_DIDL_LITE_WRITER (object));
 
         g_clear_pointer (&priv->xml_doc, av_xml_doc_unref);
 
@@ -401,12 +393,11 @@ static void
 gupnp_didl_lite_writer_finalize (GObject *object)
 {
         GObjectClass               *object_class;
-        GUPnPDIDLLiteWriterPrivate *priv;
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (
+                        GUPNP_DIDL_LITE_WRITER (object));
 
-        priv = GUPNP_DIDL_LITE_WRITER (object)->priv;
-
-        if (priv->language)
-                g_free (priv->language);
+        g_free (priv->language);
 
         object_class = G_OBJECT_CLASS (gupnp_didl_lite_writer_parent_class);
         object_class->finalize (object);
@@ -493,20 +484,22 @@ gupnp_didl_lite_writer_add_item (GUPnPDIDLLiteWriter *writer)
 {
         xmlNode *item_node;
         GUPnPDIDLLiteObject *object;
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (writer);
 
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_WRITER (writer), NULL);
 
-        item_node = xmlNewChild (writer->priv->xml_node,
-                                NULL,
-                                (unsigned char *) "item",
-                                NULL);
+        item_node = xmlNewChild (priv->xml_node,
+                                 NULL,
+                                 (unsigned char *) "item",
+                                 NULL);
 
         object = gupnp_didl_lite_object_new_from_xml (item_node,
-                                                      writer->priv->xml_doc,
-                                                      writer->priv->upnp_ns,
-                                                      writer->priv->dc_ns,
-                                                      writer->priv->dlna_ns,
-                                                      writer->priv->pv_ns);
+                                                      priv->xml_doc,
+                                                      priv->upnp_ns,
+                                                      priv->dc_ns,
+                                                      priv->dlna_ns,
+                                                      priv->pv_ns);
         return GUPNP_DIDL_LITE_ITEM (object);
 }
 
@@ -528,6 +521,8 @@ gupnp_didl_lite_writer_add_container_child_item
 {
         xmlNode *item_node, *container_node;
         GUPnPDIDLLiteObject *object;
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (writer);
 
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_CONTAINER (container), NULL);
 
@@ -540,11 +535,11 @@ gupnp_didl_lite_writer_add_container_child_item
                                  NULL);
 
         object = gupnp_didl_lite_object_new_from_xml (item_node,
-                                                      writer->priv->xml_doc,
-                                                      writer->priv->upnp_ns,
-                                                      writer->priv->dc_ns,
-                                                      writer->priv->dlna_ns,
-                                                      writer->priv->pv_ns);
+                                                      priv->xml_doc,
+                                                      priv->upnp_ns,
+                                                      priv->dc_ns,
+                                                      priv->dlna_ns,
+                                                      priv->pv_ns);
         return GUPNP_DIDL_LITE_ITEM (object);
 }
 
@@ -561,20 +556,22 @@ gupnp_didl_lite_writer_add_container (GUPnPDIDLLiteWriter *writer)
 {
         xmlNode *container_node;
         GUPnPDIDLLiteObject *object;
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (writer);
 
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_WRITER (writer), NULL);
 
-        container_node = xmlNewChild (writer->priv->xml_node,
+        container_node = xmlNewChild (priv->xml_node,
                                       NULL,
                                       (unsigned char *) "container",
                                       NULL);
 
         object = gupnp_didl_lite_object_new_from_xml (container_node,
-                                                      writer->priv->xml_doc,
-                                                      writer->priv->upnp_ns,
-                                                      writer->priv->dc_ns,
-                                                      writer->priv->dlna_ns,
-                                                      writer->priv->pv_ns);
+                                                      priv->xml_doc,
+                                                      priv->upnp_ns,
+                                                      priv->dc_ns,
+                                                      priv->dlna_ns,
+                                                      priv->pv_ns);
         return GUPNP_DIDL_LITE_CONTAINER (object);
 }
 
@@ -592,14 +589,16 @@ gupnp_didl_lite_writer_add_descriptor (GUPnPDIDLLiteWriter *writer)
         xmlNode *desc_node;
 
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_WRITER (writer), NULL);
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (writer);
 
-        desc_node = xmlNewChild (writer->priv->xml_node,
+        desc_node = xmlNewChild (priv->xml_node,
                                  NULL,
                                  (unsigned char *) "desc",
                                  NULL);
 
         return gupnp_didl_lite_descriptor_new_from_xml (desc_node,
-                                                        writer->priv->xml_doc);
+                                                        priv->xml_doc);
 }
 
 /**
@@ -617,13 +616,11 @@ gupnp_didl_lite_writer_get_string (GUPnPDIDLLiteWriter *writer)
         char      *ret;
 
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_WRITER (writer), NULL);
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (writer);
 
         buffer = xmlBufferCreate ();
-        xmlNodeDump (buffer,
-                     writer->priv->xml_doc->doc,
-                     writer->priv->xml_node,
-                     0,
-                     0);
+        xmlNodeDump (buffer, priv->xml_doc->doc, priv->xml_node, 0, 0);
         ret = g_strndup ((char *) xmlBufferContent (buffer),
                          xmlBufferLength (buffer));
         xmlBufferFree (buffer);
@@ -643,8 +640,10 @@ xmlNode *
 gupnp_didl_lite_writer_get_xml_node (GUPnPDIDLLiteWriter *writer)
 {
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_WRITER (writer), NULL);
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (writer);
 
-        return writer->priv->xml_node;
+        return priv->xml_node;
 }
 
 /**
@@ -659,8 +658,10 @@ const char *
 gupnp_didl_lite_writer_get_language (GUPnPDIDLLiteWriter *writer)
 {
         g_return_val_if_fail (GUPNP_IS_DIDL_LITE_WRITER (writer), NULL);
+        GUPnPDIDLLiteWriterPrivate *priv =
+                gupnp_didl_lite_writer_get_instance_private (writer);
 
-        return writer->priv->language;
+        return priv->language;
 }
 
 /**
