@@ -3,22 +3,12 @@
  *
  * Authors: Regis Merlino <regis.merlino@intel.com>
  *
- * This library is free software; you can redistribute it and/or
- * modify it under the terms of the GNU Library General Public
- * License as published by the Free Software Foundation; either
- * version 2 of the License, or (at your option) any later version.
+ * SPDX-License-Identifier: LGPL-2.1-or-later
  *
- * This library is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
- * Library General Public License for more details.
- *
- * You should have received a copy of the GNU Library General Public
- * License along with this library; if not, write to the
- * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
- * Boston, MA 02110-1301, USA.
  */
 
+#include <config.h>
+
 #include <libgupnp-av/gupnp-feature-list-parser.h>
 #include <stdlib.h>
 #include <string.h>
@@ -75,7 +65,7 @@ check_feature (GUPnPFeature *feature)
 }
 
 int
-main (int argc, char **argv)
+main (G_GNUC_UNUSED int argc, G_GNUC_UNUSED char **argv)
 {
         GUPnPFeatureListParser *parser;
         GError                 *error;
@@ -83,10 +73,6 @@ main (int argc, char **argv)
         GList                  *item;
         gboolean               success = TRUE;
 
-#if !GLIB_CHECK_VERSION (2, 35, 0)
-        g_type_init ();
-#endif
-
         parser = gupnp_feature_list_parser_new ();
 
         error = NULL;
